@@ -1,4 +1,4 @@
-var _bar = new WeakMap();
+var _bar = /*#__PURE__*/ new WeakMap();
 class Foo {
     static test() {
         return Foo === Foo;
